@@ -43,3 +43,5 @@ from .portrait128.model_akida_unet import akida_unet_portrait128
 
 from .gamma_constraint import add_gamma_constraint
 from .filter_pruning import delete_filters, prune_model
+from .renaming import rename_model_layers
+from .utils import fetch_file
