@@ -22,7 +22,7 @@ import os
 import pickle
 import tensorflow as tf
 
-from keras.utils.data_utils import get_file
+from ..utils import fetch_file
 
 
 def load_labels_mapping():
@@ -31,9 +31,9 @@ def load_labels_mapping():
     Returns:
         dict: the dictionnary of labels mapping
     """
-    labels_mapping_path = get_file(
-        "labels_mapping.pkl",
+    labels_mapping_path = fetch_file(
         "http://data.brainchip.com/dataset-mirror/cse_cic_ids_2018/labels_mapping.pkl",
+        fname="labels_mapping.pkl",
         cache_subdir='datasets/cse_2018/')
 
     with open(labels_mapping_path, 'rb') as handle:
@@ -48,9 +48,9 @@ def load_columns_type():
         list, dict: the list of numerical columns and the dictionary of
         categorical columns with their vocabulary
     """
-    columns_types_path = get_file(
-        "columns_types.pkl",
+    columns_types_path = fetch_file(
         "http://data.brainchip.com/dataset-mirror/cse_cic_ids_2018/columns_types.pkl",
+        fname="columns_types.pkl",
         cache_subdir='datasets/cse_2018/')
 
     with open(columns_types_path, 'rb') as handle:
@@ -76,9 +76,9 @@ def load_data(batch_size=65536, load_train=True, load_test=True):
     x_test = None
 
     if load_train:
-        train_file_path = get_file(
-            "train_set.zip",
+        train_file_path = fetch_file(
             "http://data.brainchip.com/dataset-mirror/cse_cic_ids_2018/train_set.zip",
+            fname="train_set.zip",
             cache_subdir='datasets/cse_2018/',
             extract=True)
         train_file_path = os.path.join(os.path.dirname(train_file_path),
@@ -90,9 +90,9 @@ def load_data(batch_size=65536, load_train=True, load_test=True):
                                                         ignore_errors=True)
 
     if load_test:
-        test_file_path = get_file(
-            "test_set.zip",
+        test_file_path = fetch_file(
             "http://data.brainchip.com/dataset-mirror/cse_cic_ids_2018/test_set.zip",
+            fname="test_set.zip",
             cache_subdir='datasets/cse_2018/',
             extract=True)
         test_file_path = os.path.join(os.path.dirname(test_file_path),
