@@ -23,12 +23,12 @@ import pickle
 import numpy as np
 
 from keras import Model
-from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model, quantize
 
 from ..layer_blocks import separable_conv_block
 from ..imagenet.model_akidanet import akidanet_imagenet
+from ..utils import fetch_file
 
 
 def yolo_base(input_shape=(224, 224, 3),
@@ -157,22 +157,20 @@ def yolo_widerface_pretrained():
 
     """
     anchors_name = 'widerface_anchors.pkl'
-    anchors_path = get_file(
+    anchors_path = fetch_file(
+        'http://data.brainchip.com/dataset-mirror/widerface/' + anchors_name,
         fname=anchors_name,
-        origin='http://data.brainchip.com/dataset-mirror/widerface/' +
-        anchors_name,
         file_hash='325f92336a310d83fed71765436ee343bf3e39cbc12fd099d30677761aee9376',
         cache_subdir='datasets/widerface')
     with open(anchors_path, 'rb') as handle:
         anchors = pickle.load(handle)
 
     model_name = 'yolo_akidanet_widerface_iq8_wq4_aq4.h5'
-    file_hash = '393b4167d3db09ac2abde21082dac5c438df3921a44d0620ffe60fdcd54d639f'
-    model_path = get_file(fname=model_name,
-                          origin='http://data.brainchip.com/models/yolo/' +
-                          model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
+    file_hash = '8ae212f34e66addda148c31466d18310a889cf8116c8ecd16a1a5d2d333b3385'
+    model_path = fetch_file('http://data.brainchip.com/models/yolo/' + model_name,
+                            fname=model_name,
+                            file_hash=file_hash,
+                            cache_subdir='models')
 
     return load_quantized_model(model_path), anchors
 
@@ -188,20 +186,19 @@ def yolo_voc_pretrained():
 
     """
     anchors_name = 'voc_anchors.pkl'
-    anchors_path = get_file(
+    anchors_path = fetch_file(
+        'http://data.brainchip.com/dataset-mirror/voc/' + anchors_name,
         fname=anchors_name,
-        origin='http://data.brainchip.com/dataset-mirror/voc/' + anchors_name,
         file_hash='b1fe1ed12691e100646cf52b1320f05abd17b2f546d3e12cdee87758cc9ed0ba',
         cache_subdir='datasets/voc')
     with open(anchors_path, 'rb') as handle:
         anchors = pickle.load(handle)
 
     model_name = 'yolo_akidanet_voc_iq8_wq4_aq4.h5'
-    file_hash = '5a6c5cf9614723ba717603e336cd5abbf11277bbd3a98ab042d7b23cf544bc74'
-    model_path = get_file(fname=model_name,
-                          origin='http://data.brainchip.com/models/yolo/' +
-                          model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
+    file_hash = '5893465e06a9004526a83cf2735c8cc294793cb55ab4489a11b6c2d45f6eebc0'
+    model_path = fetch_file('http://data.brainchip.com/models/yolo/' + model_name,
+                            fname=model_name,
+                            file_hash=file_hash,
+                            cache_subdir='models')
 
     return load_quantized_model(model_path), anchors
