@@ -23,7 +23,6 @@ import argparse
 import numpy as np
 import tensorflow as tf
 
-from keras.utils.data_utils import get_file
 from keras.utils.np_utils import to_categorical
 
 from cnn2snn import load_quantized_model, convert
@@ -31,6 +30,7 @@ from cnn2snn import load_quantized_model, convert
 from ..cyclic_lr import CyclicLR
 from ..training import (get_training_parser, compile_model, evaluate_model,
                         evaluate_akida_model, print_history_stats)
+from ..utils import fetch_file
 
 
 def get_data(dataset, batch_size):
@@ -48,17 +48,15 @@ def get_data(dataset, batch_size):
         samples.
     """
     # Load pre-processed dataset
-    train_file = get_file(fname=dataset + '_preprocessed_train.npz',
-                          origin=os.path.join(
-                              'http://data.brainchip.com/dataset-mirror',
-                              dataset, dataset + '_preprocessed_train.npz'),
-                          cache_subdir=os.path.join('datasets', dataset))
+    train_file = fetch_file(os.path.join('http://data.brainchip.com/dataset-mirror',
+                                         dataset, dataset + '_preprocessed_train.npz'),
+                            fname=dataset + '_preprocessed_train.npz',
+                            cache_subdir=os.path.join('datasets', dataset))
 
-    test_file = get_file(fname=dataset + '_preprocessed_test.npz',
-                         origin=os.path.join(
-                             'http://data.brainchip.com/dataset-mirror',
-                             dataset, dataset + '_preprocessed_test.npz'),
-                         cache_subdir=os.path.join('datasets', dataset))
+    test_file = fetch_file(os.path.join('http://data.brainchip.com/dataset-mirror',
+                                        dataset, dataset + '_preprocessed_test.npz'),
+                           fname=dataset + '_preprocessed_test.npz',
+                           cache_subdir=os.path.join('datasets', dataset))
     train_data = np.load(train_file)
     x_train = train_data['x_train']
     y_train = to_categorical(train_data['y_train'])
