@@ -18,13 +18,13 @@
 Convtiny model definition for DVS gesture classification.
 """
 
-from keras.utils.data_utils import get_file
 from keras import Model
 from keras.layers import Input, Reshape, Dropout, Activation
 
 from cnn2snn import load_quantized_model, quantize
 
 from ..layer_blocks import conv_block, separable_conv_block, dense_block
+from ..utils import fetch_file
 
 # Locally fixed config options
 # The number of neurons in the penultimate dense layer
@@ -36,14 +36,14 @@ BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/convtiny/'
 
 
 def convtiny_dvs_gesture(input_shape=(64, 64, 10),
-                         classes=None,
+                         classes=10,
                          weight_quantization=0,
                          activ_quantization=0):
     """Instantiates a CNN for the "IBM DVS Gesture" example.
 
     Args:
         input_shape (tuple): input shape tuple of the model
-        classes (int): number of classes to classify images into.
+        classes (int, optional): number of classes to classify images into. Defaults to 10.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -60,7 +60,7 @@ def convtiny_dvs_gesture(input_shape=(64, 64, 10),
         keras.Model: a Keras convolutional model for DVS Gesture.
     """
 
-    img_input = Input(input_shape)
+    img_input = Input(input_shape, name="input")
 
     x = conv_block(img_input,
                    filters=16,
@@ -139,6 +139,7 @@ def convtiny_dvs_gesture(input_shape=(64, 64, 10),
 
     x = dense_block(x,
                     units=classes,
+                    name='dense',
                     add_batchnorm=False,
                     add_activation=False,
                     use_bias=False)
@@ -163,8 +164,8 @@ def convtiny_gesture_pretrained():
     """
     model_name = 'convtiny_dvs_gesture_iq4_wq4_aq4.h5'
     file_hash = '8a9ccf3ecb38de38ac1119ec2e6713a15bfb4dd9c630b1356a2dd7071ddbcef6'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
+    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
+                            fname=model_name,
+                            file_hash=file_hash,
+                            cache_subdir='models')
     return load_quantized_model(model_path)
