@@ -18,13 +18,13 @@
 Convtiny model definition for DVS handy classification.
 """
 
-from keras.utils.data_utils import get_file
 from keras import Model
 from keras.layers import Input, Reshape, Dropout, Activation
 
 from cnn2snn import load_quantized_model, quantize
 
 from ..layer_blocks import conv_block, separable_conv_block, dense_block
+from ..utils import fetch_file
 
 # Locally fixed config options
 # The number of neurons in the penultimate dense layer
@@ -36,14 +36,14 @@ BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/convtiny/'
 
 
 def convtiny_dvs_handy(input_shape=(120, 160, 2),
-                       classes=None,
+                       classes=9,
                        weight_quantization=0,
                        activ_quantization=0):
     """Instantiates a CNN for "Brainchip dvs_handy" example.
 
     Args:
         input_shape (tuple): input shape tuple of the model
-        classes (int): number of classes to classify images into.
+        classes (int, optional): number of classes to classify images into. Defaults to 9.
         weight_quantization (int): sets all weights in the model to have
             a particular quantization bitwidth except for the weights in the
             first layer.
@@ -60,7 +60,7 @@ def convtiny_dvs_handy(input_shape=(120, 160, 2),
         keras.Model: a Keras convolutional model for DVS Gesture.
     """
 
-    img_input = Input(input_shape)
+    img_input = Input(input_shape, name="input")
 
     x = conv_block(img_input,
                    filters=16,
@@ -151,6 +151,7 @@ def convtiny_dvs_handy(input_shape=(120, 160, 2),
 
     x = dense_block(x,
                     units=classes,
+                    name='dense',
                     add_batchnorm=False,
                     add_activation=False,
                     use_bias=False)
@@ -176,8 +177,8 @@ def convtiny_handy_samsung_pretrained():
     """
     model_name = 'convtiny_dvs_handy_samsung_iq4_wq4_aq4.h5'
     file_hash = '0e7d9e698c62b7e8f4bd2f95c7f226615c316cdef1175d9af3899dbfae6441e9'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
+    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
+                            fname=model_name,
+                            file_hash=file_hash,
+                            cache_subdir='models')
     return load_quantized_model(model_path)
