@@ -44,6 +44,26 @@ from .preprocessing import preprocess_image, DATA_AUGMENTATION
 from ..training import (get_training_parser, freeze_model_before, print_history_stats,
                         EarlyStoppingCalibration)
 from ..transformers.model_vit import apply_embedding_weights
+from ..distiller import DeitDistiller
+
+
+def _load_model(model_path):
+    """Combine the cnn2snn.load_quantized_model and quantizeml.load_model
+
+    Args:
+        model_path (str): model path
+
+    Returns:
+        keras.Model: the load model
+    """
+    try:
+        model = load_quantized_model(model_path)
+    except Exception:
+        try:
+            model = load_model(model_path)
+        except Exception as e:
+            raise e.__class__('Cannot load provided model.')
+    return model
 
 
 def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=True, one_hot=False):
@@ -104,16 +124,19 @@ def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=T
     return dataset, infos.splits[split].num_examples / batch_size
 
 
-def compile_model(model, optimizer="SGD"):
+def compile_model(model, optimizer="SGD", distiller_type="none"):
     """ Compiles the model.
 
     Args:
         model (keras.Model): the model to compile
         optimizer (str, optional): the optimizer to use. Defaults to "SGD".
+        distiller_type (str, optional): string to select the loss in distillation.
+            Only used when input model is of ``DeitDistiller`` type. Defaults to 'none'.
 
     Returns:
         bool: True if labels should be one-hot encoded, False if not.
     """
+
     def _get_optim(optim_str):
         optim_str_low = optim_str.lower()
         if optim_str_low == "sgd":
@@ -126,6 +149,13 @@ def compile_model(model, optimizer="SGD"):
             raise ValueError(f"Unknown optimizer {optim_str}. "
                              "Please choose one of these options: {SGD, ADAM, LAMB}")
 
+    if isinstance(model, DeitDistiller):
+        model.compile(optimizer=_get_optim(optimizer),
+                      metrics=['accuracy', 'top_k_categorical_accuracy'],
+                      student_loss_fn=keras.losses.CategoricalCrossentropy(from_logits=True),
+                      distiller_type=distiller_type)
+        return True
+
     # Preserve legacy behavior where models have a softmax activation at the end
     if isinstance(model.layers[-2], Activation):
         model.compile(optimizer=_get_optim(optimizer),
@@ -343,7 +373,7 @@ def train(model,
             LR_EPOCH_CONSTANT = 5  # number of epochs you first keep the learning rate constant
             LR_MIN = 1e-6
         # Make sure to start with a learning rate higher than LR_MIN
-        LR_MIN = LR_MIN if LR_START > LR_MIN else 0.1*LR_START
+        LR_MIN = LR_MIN if LR_START > LR_MIN else 0.1 * LR_START
 
         # If the number of epochs is too small, dont use WARMUP_LR
         if num_epochs < LR_EPOCH_CONSTANT:
@@ -462,6 +492,14 @@ def main():
                               action='store_true',
                               help="Use cosine learning rate scheduler instead of the exponential \
                                     default.")
+    train_parser.add_argument("--teacher", type=str, default=None,
+                              help="Teacher model use to train the model through Knowledge"
+                              "Distillation. The input model output an Add layer. "
+                              "Defaults to %(default)s.")
+    train_parser.add_argument("-dt", "--distiller_type", type=str, default="soft",
+                              help="Define the distillation loss type. Defaults to %(default)s.")
+    train_parser.add_argument("-a", "--alpha", type=float, default=0.5,
+                              help="Value for distiller losses weighting. Defaults to %(default)s.")
 
     tune_parser = parsers[2]
     tune_parser.add_argument("-ie",
@@ -485,6 +523,14 @@ def main():
                              action='store_true',
                              help="Use cosine learning rate scheduler instead of the exponential \
                                    default.")
+    tune_parser.add_argument("--teacher", type=str, default=None,
+                             help="Teacher model use to train the model through Knowledge"
+                             "Distillation. The input model output an Add layer. "
+                             "Defaults to %(default)s.")
+    tune_parser.add_argument("-dt", "--distiller_type", type=str, default="soft",
+                             help="Define the distillation loss type. Defaults to %(default)s.")
+    tune_parser.add_argument("-a", "--alpha", type=float, default=0.5,
+                             help="Value for distiller losses weighting. Defaults to %(default)s.")
 
     eval_parser = parsers[3]
     eval_parser.add_argument("-ns",
@@ -511,20 +557,25 @@ def main():
     args = parsers[0].parse_args()
 
     # Load the source model
-    try:
-        model = load_quantized_model(args.model)
-    except Exception:
-        try:
-            model = load_model(args.model)
-        except Exception as e:
-            raise e.__class__('Cannot load provided model.')
+    model = _load_model(args.model)
+
+    # Try to load the teacher model, used after to train with Knowledge Distillation
+    # Hyperparameters takes from https://arxiv.org/pdf/2012.12877.pdf
+    if getattr(args, 'teacher', False):
+        if args.distiller_type not in ['none', 'soft', 'hard']:
+            raise ValueError("Distiller type must be one of ['none', 'soft', 'hard']")
+        teacher = _load_model(args.teacher)
+        train_model = DeitDistiller(model, teacher, alpha=args.alpha, temperature=3.0)
+    else:
+        train_model = model
 
     # Freeze the model
     if "freeze_before" in args:
         freeze_model_before(model, args.freeze_before)
 
     # Compile model
-    one_hot = compile_model(model, optimizer=getattr(args, "optim", "SGD"))
+    one_hot = compile_model(train_model, optimizer=getattr(args, "optim", "SGD"),
+                            distiller_type=getattr(args, "distiller_type", "none"))
 
     # Load validation data
     if args.action != 'rescale':
@@ -548,7 +599,7 @@ def main():
             # Tune learning rate following https://arxiv.org/pdf/2012.12877.pdf
             learning_rate *= args.batch_size / 512
 
-        train(model,
+        train(train_model,
               train_ds,
               train_steps,
               val_ds,
