@@ -21,12 +21,12 @@ spike extractor and a classification layer.
 """
 
 from keras import Model
-from keras.utils.data_utils import get_file
 from keras.layers import Reshape, Activation
 
 from cnn2snn import load_quantized_model, quantize_layer
 
 from ..layer_blocks import separable_conv_block, dense_block
+from ..utils import fetch_file
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/mobilenet_edge/'
 
@@ -84,7 +84,7 @@ def mobilenet_edge_imagenet(base_model, classes):
 
     # Quantize edge layers
     model = quantize_layer(model, 'spike_generator', wq)
-    model = quantize_layer(model, 'spike_generator_relu', 1)
+    model = quantize_layer(model, 'spike_generator/relu', 1)
     # NOTE: quantization set to 2 here, to be as close as
     # possible to the Akida native layer that will replace this one,
     # with binary weights.
@@ -102,9 +102,9 @@ def mobilenet_edge_imagenet_pretrained():
 
     """
     model_name = 'mobilenet_imagenet_224_alpha_50_edge_iq8_wq4_aq4.h5'
-    file_hash = '1b3427187fc237829752bfaf0926178d9e2df854fe9bd141bc19afc48efba2c7'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
+    file_hash = 'b759ed6aa5b47923e5cee03f756e63d7a5865e49f34749e55aff242d83b9ee75'
+    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
+                            fname=model_name,
+                            file_hash=file_hash,
+                            cache_subdir='models')
     return load_quantized_model(model_path)
