@@ -22,12 +22,12 @@ import os
 import pickle
 
 from keras.utils.np_utils import to_categorical
-from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model, quantize_layer, convert
 
 from ..cyclic_lr import CyclicLR
 from ..training import get_training_parser, compile_model, evaluate_model, print_history_stats
+from ..utils import fetch_file
 
 
 def get_data():
@@ -37,9 +37,9 @@ def get_data():
         tuple: train data, train labels, validation data and validation labels
     """
     # Load pre-processed dataset
-    fname = get_file(
+    fname = fetch_file(
+        'http://data.brainchip.com/dataset-mirror/kws/kws_preprocessed_all_words_except_backward_follow_forward.pkl',
         fname='kws_preprocessed_all_words_except_backward_follow_forward.pkl',
-        origin='http://data.brainchip.com/dataset-mirror/kws/kws_preprocessed_all_words_except_backward_follow_forward.pkl',
         cache_subdir=os.path.join('datasets', 'kws'))
 
     print('Loading pre-processed dataset...')
