@@ -20,11 +20,11 @@ DS-CNN model definition for KWS classification.
 
 from keras import Model
 from keras.layers import (Input, Reshape, Activation, Flatten, Rescaling)
-from keras.utils.data_utils import get_file
 
 from cnn2snn import load_quantized_model, quantize
 
 from ..layer_blocks import conv_block, separable_conv_block, dense_block
+from ..utils import fetch_file
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/ds_cnn/'
 
@@ -83,13 +83,13 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
     if include_top and not classes:
         raise ValueError("If 'include_top' is True, 'classes' must be set.")
 
-    img_input = Input(shape=input_shape)
+    img_input = Input(shape=input_shape, name="input")
 
     if input_scaling is None:
         x = img_input
     else:
         scale, offset = input_scaling
-        x = Rescaling(1. / scale, offset)(img_input)
+        x = Rescaling(1. / scale, offset, name="rescaling")(img_input)
 
     x = conv_block(x,
                    filters=64,
@@ -137,7 +137,7 @@ def ds_cnn_kws(input_shape=(49, 10, 1),
     x = Reshape(shape, name='reshape_1')(x)
 
     if include_top:
-        x = Flatten()(x)
+        x = Flatten(name="flatten")(x)
         x = dense_block(x,
                         units=classes,
                         name='dense_5',
@@ -169,9 +169,9 @@ def ds_cnn_kws_pretrained():
 
     """
     model_name = 'ds_cnn_kws_iq8_wq4_aq4_laq1.h5'
-    file_hash = 'eb0cfd4c4ba07d9f149551ad82aef089ca619d1922be235ddcc5e3562041a50b'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
+    file_hash = '6b8a7c2f74de1dc3ad18cbb7746910f069b2d56fbc9b2c40180599bf2bc78edf'
+    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
+                            fname=model_name,
+                            file_hash=file_hash,
+                            cache_subdir='models')
     return load_quantized_model(model_path)
