@@ -52,13 +52,13 @@ def _add_pooling_layer(x, pooling_type, pool_size, padding, layer_base_name):
     if pooling_type == 'max':
         return MaxPool2D(pool_size=pool_size,
                          padding=padding,
-                         name=layer_base_name + '_maxpool')(x)
+                         name=layer_base_name + '/maxpool')(x)
     if pooling_type == 'avg':
         return AvgPool2D(pool_size=pool_size,
                          padding=padding,
-                         name=layer_base_name + '_avgpool')(x)
+                         name=layer_base_name + '/avgpool')(x)
     if pooling_type == 'global_avg':
-        return GlobalAvgPool2D(name=layer_base_name + '_global_avg')(x)
+        return GlobalAvgPool2D(name=layer_base_name + '/global_avg')(x)
     raise ValueError("'pooling_type' argument must be 'max', 'avg' or 'global_avg'.")
 
 
@@ -109,10 +109,10 @@ def conv_block(inputs,
                                conv_layer.name)
 
     if add_batchnorm:
-        x = BatchNormalization(name=conv_layer.name + '_BN')(x)
+        x = BatchNormalization(name=conv_layer.name + '/BN')(x)
 
     if add_activation:
-        x = ReLU(6.0, name=conv_layer.name + '_relu')(x)
+        x = ReLU(6.0, name=conv_layer.name + '/relu')(x)
 
     return x
 
@@ -168,10 +168,10 @@ def separable_conv_block(inputs,
                                sep_conv_layer.name)
 
     if add_batchnorm:
-        x = BatchNormalization(name=sep_conv_layer.name + '_BN')(x)
+        x = BatchNormalization(name=sep_conv_layer.name + '/BN')(x)
 
     if add_activation:
-        x = ReLU(6.0, name=sep_conv_layer.name + '_relu')(x)
+        x = ReLU(6.0, name=sep_conv_layer.name + '/relu')(x)
 
     return x
 
@@ -202,10 +202,10 @@ def dense_block(inputs,
     x = dense_layer(inputs)
 
     if add_batchnorm:
-        x = BatchNormalization(name=dense_layer.name + '_BN')(x)
+        x = BatchNormalization(name=dense_layer.name + '/BN')(x)
 
     if add_activation:
-        x = ReLU(6.0, name=dense_layer.name + '_relu')(x)
+        x = ReLU(6.0, name=dense_layer.name + '/relu')(x)
 
     return x
 
@@ -361,8 +361,8 @@ def transformer_block(inputs, num_heads, hidden_size, mlp_dim, dropout, name,
             choose from GeLU, ReLUx or swish activation in the MLP block. Defaults to "GeLU".
 
     Returns:
-        (tf.Tensor, (tf.Tensor tf.Tensor)): block outputs and (attention softmaxed scores, the
-            normalized sum of inputs and attention outputs)
+        (tf.Tensor, (tf.Tensor, tf.Tensor)): block outputs and (attention softmaxed scores, the
+        normalized sum of inputs and attention outputs)
     """
     x = norm_to_layer(norm)(epsilon=1e-6, name=f"{name}/LayerNorm_0")(inputs)
     x, weights = multi_head_attention(x,
@@ -413,10 +413,10 @@ def conv_transpose_block(inputs,
     x = conv_trans_layer(inputs)
 
     if add_batchnorm:
-        x = BatchNormalization(name=conv_trans_layer.name + '_BN')(x)
+        x = BatchNormalization(name=conv_trans_layer.name + '/BN')(x)
 
     if add_activation:
-        x = ReLU(8.0, name=conv_trans_layer.name + '_relu')(x)
+        x = ReLU(8.0, name=conv_trans_layer.name + '/relu')(x)
 
     return x
 
