@@ -63,15 +63,14 @@ def train_model(model, teacher_model, x_train, y_train, batch_size, epochs):
         epochs (int): the number of epochs
     """
     # Create a distiller
-    distiller = Distiller(student=model, teacher=teacher_model)
+    distiller = Distiller(student=model, teacher=teacher_model, alpha=0.1)
 
     # Compile the distiller
     distiller.compile(
         optimizer=Adam(learning_rate=5e-5),
         metrics=[SparseCategoricalAccuracy()],
         student_loss_fn=SparseCategoricalCrossentropy(from_logits=True),
-        distillation_loss_fn=KLDistillationLoss(temperature=10),
-        alpha=0.1)
+        distillation_loss_fn=KLDistillationLoss(temperature=10))
 
     # Train the model
     history = distiller.fit(x_train, y_train, batch_size, epochs)
