@@ -20,11 +20,11 @@ GXNOR model definition for MNIST classification.
 
 from keras import Model
 from keras.layers import Input, Flatten, Rescaling
-from keras.utils.data_utils import get_file
 
 from cnn2snn import quantize, load_quantized_model
 
 from ..layer_blocks import conv_block, dense_block
+from ..utils import fetch_file
 
 BASE_WEIGHT_PATH = 'http://data.brainchip.com/models/gxnor/'
 
@@ -64,13 +64,13 @@ def gxnor_mnist(weight_quantization=0,
     if input_weight_quantization is None:
         input_weight_quantization = weight_quantization
 
-    img_input = Input(shape=(28, 28, 1))
-    x = Rescaling(1. / 255)(img_input)
+    img_input = Input(shape=(28, 28, 1), name="input")
+    x = Rescaling(1. / 255, name="rescaling")(img_input)
 
     # Block 1
     x = conv_block(x,
                    filters=32,
-                   name='block1_conv1',
+                   name='block_1/conv_1',
                    kernel_size=(5, 5),
                    padding='same',
                    add_batchnorm=True,
@@ -81,7 +81,7 @@ def gxnor_mnist(weight_quantization=0,
     # Block 2
     x = conv_block(x,
                    filters=64,
-                   name='block2_conv1',
+                   name='block_2/conv_1',
                    kernel_size=(3, 3),
                    padding='same',
                    add_batchnorm=True,
@@ -93,7 +93,7 @@ def gxnor_mnist(weight_quantization=0,
     x = Flatten(name='flatten')(x)
     x = dense_block(x,
                     units=512,
-                    name='fc1',
+                    name='fc_1',
                     add_batchnorm=True,
                     add_activation=True)
     x = dense_block(x,
@@ -133,8 +133,8 @@ def gxnor_mnist_pretrained():
     """
     model_name = 'gxnor_mnist_iq2_wq2_aq1.h5'
     file_hash = '00f6999dc8f17f701c8998106dcfc862c305a4611d89cec20932a83bb52c1719'
-    model_path = get_file(fname=model_name,
-                          origin=BASE_WEIGHT_PATH + model_name,
-                          file_hash=file_hash,
-                          cache_subdir='models')
+    model_path = fetch_file(BASE_WEIGHT_PATH + model_name,
+                            fname=model_name,
+                            file_hash=file_hash,
+                            cache_subdir='models')
     return load_quantized_model(model_path)
