@@ -22,8 +22,11 @@ import argparse
 import numpy as np
 
 from keras.preprocessing.image import DirectoryIterator
-from keras.optimizer_v2.adam import Adam
+from keras.optimizers import Adam
 from keras.layers import Activation
+from keras.callbacks import Callback
+
+from quantizeml.models import set_calibrate
 
 
 def compile_model(model,
@@ -269,3 +272,25 @@ def print_history_stats(history):
     for key, values in clean_history.items():
         values = "\t".join(f"{f(values):.4f}" for f in stats)
         print(f"{key}\t{values}")
+
+
+class EarlyStoppingCalibration(Callback):
+    """A callback that limits the number of epochs to calibrate the model,
+        increasing the speed of the training.
+
+    Args:
+        trigger_epoch (int, optional): epoch at which to end the calibration.
+            Defaults to calibrate until the end of the training.
+
+    Notes:
+        If the :attr:`trigger_epoch` is set to 0, the model will never be calibrated
+    """
+
+    def __init__(self, trigger_epoch=-1):
+        self.trigger_epoch = trigger_epoch
+
+    def on_epoch_begin(self, epoch, logs=None):
+        calibrate = epoch < self.trigger_epoch or self.trigger_epoch < 0
+        set_calibrate(self.model, calibrate)
+        if logs is not None:
+            logs["calibrating"] = calibrate
